﻿using System;
using System.ComponentModel;
using System.Runtime.CompilerServices;
using System.Xml.Linq;
using Maps = Infragistics.Controls.Maps;
using System.Collections.Generic;
using System.Diagnostics;

namespace GeoMapSampleProject
{
    public class LocalMapImagery : Maps.GeographicMapImagery
    {
        public LocalMapImagery(string path) : base(new LocalMapTileSource(path)) { }
    }

    public class LocalMapTileSource : Maps.XamMultiScaleTileSource
    {
        private readonly string _originalPath;

        public LocalMapTileSource(string path)
        //  : base(3033, 3033, 256, 256, 0)
        // using size of tiles that match rest of imagery tiles for full -180, +180 long,
           : base(134217728, 134217728, 256, 256, 0)
        {
            _originalPath = path + @"\Tiles\{Z}\{X}\{Y}.png";
        }

        protected override void GetTileLayers(
            int tileLevel, int tilePositionX, int tilePositionY, 
            IList<object> tileImageLayerSources)
        {
            var zoom = tileLevel - 8;
            var invY = (int)Math.Pow(2.0, zoom) - tilePositionY - 1;

            var x = tilePositionX.ToString();
            var y = invY.ToString();
            if (zoom > 0)
            {
                var uriString = _originalPath;
                uriString = uriString.Replace("{Z}", zoom.ToString());
                uriString = uriString.Replace("{X}", x);
                uriString = uriString.Replace("{Y}", y);
                tileImageLayerSources.Add(new Uri(uriString));
            }
            var info = " ";
            info += tileLevel + "t ";
            info += zoom + "z ";
            info += x + "x ";
            info += y + "y "; 
            Debug.WriteLine(info);
        }
    }
     
}
