﻿using Infragistics.Controls.Maps;
using System.Diagnostics;
using System.IO;
using System.Windows;

namespace GeoMapSampleProject
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    { 
        public string LocalPath = Directory.GetCurrentDirectory();

        public MainWindow()
        {
            InitializeComponent();

            LocalPath = Directory.GetCurrentDirectory(); 
            DataContext = new MainWindowViewModel(LocalPath);

            // increasing max zoom level by decreasing WindowRectMinWidth
            GeoMap.WindowRectMinWidth = GeoMap.WindowRectMinWidth / 10; 

            // this rect does not have correct aspect ratio and map will be stratched/shrunk
            //GeoMap.WorldRect = new Rect(8.3713675, 46.7982968, 0.0119369, 0.0081759);
            
            // setting world rect with aspect ratio that matches 
            // orginal GeoMap aspect ratio
            GeoMap.WorldRect = new Rect(8.12735465116279, 46.7093744577618, 0.475775193798448, .1711526281223);
            GeoMap.Loaded += GeoMap_Loaded;
        }

        private void GeoMap_Loaded(object sender, RoutedEventArgs e)
        {
            // using custom imagery to show X, Y, Z numbers of tiles in Debug console (e.g. 10z 537x 361y) 
            var imagery = new ThunderForestImagery();
            imagery.MapStyle = ThunderForestIStyle.TransportLight;
            GeoMap.BackgroundContent = imagery;

            // LocalMapImagery should either 
            // - convert X, Y, Z numbers of tiles to local names of tiles
            // OR 
            // - rename local tiles to number of tiles that the GeoMap expects for geo-location of these images
            // GeoMap.BackgroundContent = new LocalMapImagery(LocalPath);

            GeoMap.WindowRectChanged += GeoMap_WindowRectChanged;
        }

        private void GeoMap_WindowRectChanged(object sender, Infragistics.RectChangedEventArgs e)
        {
            var rct1 = GeoMap.WindowRect;
            var geo1 = GeoMap.GetGeographicFromZoom(rct1);
            Debug.WriteLine("geo " + geo1); 

        }
    }
}
